==> immibis-core_50.0.0pr1_for_1.3.2-joined.jar: mod_shared/immibis/core/BlockCombined.java <==
package immibis.core;

import immibis.core.api.Dir;
import immibis.core.api.porting.SidedProxy;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

import net.minecraft.src.*;

public abstract class BlockCombined extends BlockContainer {
	
	private static Random random = new Random();
	
	public ItemCombined item;
	public final String texfile;
	
	public boolean getEnableStats() {return false;}
	
	public BlockCombined(int i, Material m, String texfile) {
		super(i, m);
		this.texfile = texfile;
		if(texfile == null)
			throw new NullPointerException("texfile");
		SidedProxy.instance.preloadTexture(texfile);
		/* $if client2$ */
		try {
			isDefaultTexture = false;
			setTextureFile(texfile);
		} catch(Error e) {
			// Older Forge; that's ok
		}
		/* $endif$ */
		/* $if mc >= 1.3$ */
		setCreativeTab(CreativeTabs.tabMisc);
		/* $endif$ */
		setHardness(2.0F);
	}
	
	public void onBlockPlacedBy(World w, int x, int y, int z, EntityLiving player)
    {
		TileCombined te = (TileCombined)w.getBlockTileEntity(x, y, z);
        
		/* $if mc >= 1.3$ */
		Vec3 look = player.getLook(1.0f);
		/* $else$
        Vec3D look = player.getLook(1.0f);
        $endif$ */
        
        double absx = Math.abs(look.xCoord);
        double absy = Math.abs(look.yCoord);
        double absz = Math.abs(look.zCoord);
        
        if(absx > absy && absx > absz) {
        	if(look.xCoord < 0)
        		te.onPlaced(player, Dir.NX);
        	else
        		te.onPlaced(player, Dir.PX);
        } else if(absy > absz) {
        	if(look.yCoord < 0)
        		te.onPlaced(player, Dir.NY);
        	else
        		te.onPlaced(player, Dir.PY);
        } else {
        	if(look.zCoord < 0)
        		te.onPlaced(player, Dir.NZ);
        	else
        		te.onPlaced(player, Dir.PZ);
        }
    }
	
	@Override
	public boolean canProvidePower() {
        return true;
    }
	
	@Override
	public boolean isPoweringTo(IBlockAccess world, int x, int y, int z, int i) {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			return te.redstone_output;
		return false;
	}
	
	@Override
	public boolean isIndirectlyPoweringTo(World world, int x, int y, int z, int i) {
		return isPoweringTo(world, x, y, z, i);
	}
	
	@Override
	public ArrayList getBlockDropped(World world, int i, int j, int k, int l, int i1)
	{
		ArrayList list = new ArrayList();
		list.add(new ItemStack(this, 1, l));
		return list;
	}
	
	public List<ItemStack> getInventoryDrops(World world, int x, int y, int z) {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		return te.getInventoryDrops();
	}
	
	@Override
	public abstract int getBlockTextureFromSideAndMetadata(int side, int data);
	
	@Override
	public int getRenderType() {
		return 0;
	}
	
	@Override
	public void onNeighborBlockChange(World w, int x, int y, int z, int i)
	{
		if(w.isRemote)
			return;
		TileCombined te = (TileCombined)w.getBlockTileEntity(x, y, z);
		if(te != null)
			te.onBlockNeighbourChange();
	}
	
	@Override
	/* $if mc >= 1.3$ */
	public boolean onBlockActivated(World world, int x, int y, int z, EntityPlayer player, int par6, float par7, float par8, float par9)
	/* $else$
	public boolean blockActivated(World world, int x, int y, int z, EntityPlayer player)
	$endif$ */
    {
		if(player.isSneaking())
			return false;
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			return te.onBlockActivated(player);
		return false;
    }
	
	@Override
	/* $if mc >= 1.3$ */
	public void breakBlock(World world, int x, int y, int z, int par5, int par6)
	/* $else$
	public void onBlockRemoval(World world, int x, int y, int z)
    $endif$ */
    {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			te.onBlockRemoval();
		
		List<ItemStack> drops = getInventoryDrops(world, x, y, z);
		for(ItemStack stack : drops) {
			float xpos = x + random.nextFloat() * 0.8f + 0.1f;
			float ypos = y + random.nextFloat() * 0.8f + 0.1f;
			float zpos = z + random.nextFloat() * 0.8f + 0.1f;
			
			//System.out.println("drop "+stack + " at "+xpos+","+ypos+","+zpos);
			
			// chests do this (multiple drops per stack, 10-30 items at a time)
			int left = stack.stackSize;
			while(left > 0) {
				int removeCount = Math.min(random.nextInt(21) + 10, left);
				left -= removeCount;
				
				EntityItem ent = new EntityItem(world, xpos, ypos, zpos, new ItemStack(stack.itemID, removeCount, stack.getItemDamage()));
				
				ent.motionX = random.nextGaussian() * 0.05f;
				ent.motionY = random.nextGaussian() * 0.05f + 0.2f;
				ent.motionZ = random.nextGaussian() * 0.05f;
				
				if(stack.hasTagCompound())
					ent.item.setTagCompound(stack.getTagCompound());
				
				world.spawnEntityInWorld(ent);
	        }
		}
		/* $if mc >= 1.3$ */
		super.breakBlock(world, x, y, z, par5, par6);
		/* $else$
		super.onBlockRemoval(world, x, y, z);
	    $endif$ */
    }
	
	/* $if mc < 1.3$
	@Override
	public abstract TileEntity getBlockEntity(int data);
	
	@Override
	public TileEntity getBlockEntity() {
		throw new UnsupportedOperationException("");
	}
	
	$else$ */
	public abstract TileEntity getBlockEntity(int data);
	@Override
	public final TileEntity createNewTileEntity(World world) {
		throw new UnsupportedOperationException();
	}
	@Override
	public final TileEntity createNewTileEntity(World world, int meta) {
		return getBlockEntity(meta);
	}
	/* $endif$ */

	@Override
	public String getTextureFile() {
		if(texfile == null)
			return "/terrain.png"; // work around a bug in newer Forge's Block.<init>
		return texfile;
	}
	
	@Override
    public abstract void addCreativeItems(ArrayList arraylist);
	
	/* $if mc > 1.3$ */
	@Override
	public final void getSubBlocks(int par1, CreativeTabs par2CreativeTabs, List par3List) {
		ArrayList al = new ArrayList();
		addCreativeItems(al);
		par3List.addAll(al);
	}
	/* $endif$ */
}

==> immibis-core_50.2.0_for_1.3.2-joined.jar: mod_shared/immibis/core/BlockCombined.java <==
package immibis.core;

import immibis.core.api.Dir;
import immibis.core.api.porting.SidedProxy;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

import net.minecraft.src.*;

public abstract class BlockCombined extends BlockContainer {
	
	private static Random random = new Random();
	
	public ItemCombined item;
	public final String texfile;
	
	public boolean getEnableStats() {return false;}
	
	public BlockCombined(int i, Material m, String texfile) {
		super(i, m);
		this.texfile = texfile;
		if(texfile == null)
			throw new NullPointerException("texfile");
		SidedProxy.instance.preloadTexture(texfile);
		/* $if client2$ */
		try {
			isDefaultTexture = false;
			setTextureFile(texfile);
		} catch(Error e) {
			// Older Forge; that's ok
		}
		/* $endif$ */
		/* $if mc >= 1.3$ */
		setCreativeTab(CreativeTabs.tabMisc);
		/* $endif$ */
		setHardness(2.0F);
	}
	
	public void onBlockPlacedBy(World w, int x, int y, int z, EntityLiving player)
    {
		TileCombined te = (TileCombined)w.getBlockTileEntity(x, y, z);
        
		/* $if mc >= 1.3$ */
		Vec3 look = player.getLook(1.0f);
		/* $else$
        Vec3D look = player.getLook(1.0f);
        $endif$ */
        
        double absx = Math.abs(look.xCoord);
        double absy = Math.abs(look.yCoord);
        double absz = Math.abs(look.zCoord);
        
        if(absx > absy && absx > absz) {
        	if(look.xCoord < 0)
        		te.onPlaced(player, Dir.NX);
        	else
        		te.onPlaced(player, Dir.PX);
        } else if(absy > absz) {
        	if(look.yCoord < 0)
        		te.onPlaced(player, Dir.NY);
        	else
        		te.onPlaced(player, Dir.PY);
        } else {
        	if(look.zCoord < 0)
        		te.onPlaced(player, Dir.NZ);
        	else
        		te.onPlaced(player, Dir.PZ);
        }
    }
	
	@Override
	public boolean canProvidePower() {
        return true;
    }
	
	@Override
	public boolean isPoweringTo(IBlockAccess world, int x, int y, int z, int i) {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			return te.redstone_output;
		return false;
	}
	
	@Override
	/* $if mc < 1.4$
	public boolean isIndirectlyPoweringTo(World world, int x, int y, int z, int i) {
	$else$ */
	public boolean isIndirectlyPoweringTo(IBlockAccess world, int x, int y, int z, int i) {
	/* $endif$ */
		return isPoweringTo(world, x, y, z, i);
	}
	
	@Override
	public ArrayList getBlockDropped(World world, int i, int j, int k, int l, int i1)
	{
		ArrayList list = new ArrayList();
		list.add(new ItemStack(this, 1, l));
		return list;
	}
	
	public List<ItemStack> getInventoryDrops(World world, int x, int y, int z) {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		return te.getInventoryDrops();
	}
	
	@Override
	public abstract int getBlockTextureFromSideAndMetadata(int side, int data);
	
	@Override
	public int getRenderType() {
		return 0;
	}
	
	@Override
	public void onNeighborBlockChange(World w, int x, int y, int z, int i)
	{
		if(w.isRemote)
			return;
		TileCombined te = (TileCombined)w.getBlockTileEntity(x, y, z);
		if(te != null)
			te.onBlockNeighbourChange();
	}
	
	@Override
	/* $if mc >= 1.3$ */
	public boolean onBlockActivated(World world, int x, int y, int z, EntityPlayer player, int par6, float par7, float par8, float par9)
	/* $else$
	public boolean blockActivated(World world, int x, int y, int z, EntityPlayer player)
	$endif$ */
    {
		if(player.isSneaking())
			return false;
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			return te.onBlockActivated(player);
		return false;
    }
	
	@Override
	/* $if mc >= 1.3$ */
	public void breakBlock(World world, int x, int y, int z, int par5, int par6)
	/* $else$
	public void onBlockRemoval(World world, int x, int y, int z)
    $endif$ */
    {
		TileCombined te = (TileCombined)world.getBlockTileEntity(x, y, z);
		if(te != null)
			te.onBlockRemoval();
		
		List<ItemStack> drops = getInventoryDrops(world, x, y, z);
		for(ItemStack stack : drops) {
			float xpos = x + random.nextFloat() * 0.8f + 0.1f;
			float ypos = y + random.nextFloat() * 0.8f + 0.1f;
			float zpos = z + random.nextFloat() * 0.8f + 0.1f;
			
			//System.out.println("drop "+stack + " at "+xpos+","+ypos+","+zpos);
			
			// chests do this (multiple drops per stack, 10-30 items at a time)
			int left = stack.stackSize;
			while(left > 0) {
				int removeCount = Math.min(random.nextInt(21) + 10, left);
				left -= removeCount;
				
				EntityItem ent = new EntityItem(world, xpos, ypos, zpos, new ItemStack(stack.itemID, removeCount, stack.getItemDamage()));
				
				ent.motionX = random.nextGaussian() * 0.05f;
				ent.motionY = random.nextGaussian() * 0.05f + 0.2f;
				ent.motionZ = random.nextGaussian() * 0.05f;
				
				if(stack.hasTagCompound())
					ent.item.setTagCompound(stack.getTagCompound());
				
				world.spawnEntityInWorld(ent);
	        }
		}
		/* $if mc >= 1.3$ */
		super.breakBlock(world, x, y, z, par5, par6);
		/* $else$
		super.onBlockRemoval(world, x, y, z);
	    $endif$ */
    }
	
	/* $if mc < 1.3$
	@Override
	public abstract TileEntity getBlockEntity(int data);
	
	@Override
	public TileEntity getBlockEntity() {
		return null; // BC3 workaround
		//throw new UnsupportedOperationException();
	}
	
	$else$ */
	public abstract TileEntity getBlockEntity(int data);
	@Override
	public final TileEntity createNewTileEntity(World world) {
		if(world == null) return null; // BC3 workaround
		throw new UnsupportedOperationException();
	}
	@Override
	public final TileEntity createNewTileEntity(World world, int meta) {
		return getBlockEntity(meta);
	}
	/* $endif$ */

	@Override
	public String getTextureFile() {
		if(texfile == null)
			return "/terrain.png"; // work around a bug in newer Forge's Block.<init>
		return texfile;
	}
	
	@Override
    public abstract void addCreativeItems(ArrayList arraylist);
	
	/* $if mc > 1.3$ */
	@Override
	public final void getSubBlocks(int par1, CreativeTabs par2CreativeTabs, List par3List) {
		ArrayList al = new ArrayList();
		addCreativeItems(al);
		par3List.addAll(al);
	}
	/* $endif$ */
}
